summaryrefslogtreecommitdiff
path: root/include/sys/sendfile.h
diff options
context:
space:
mode:
authorEric Andersen <andersen@codepoet.org>2002-11-14 00:55:46 +0000
committerEric Andersen <andersen@codepoet.org>2002-11-14 00:55:46 +0000
commit1a953df3b4e0545c5d42f656834346ec16cf2654 (patch)
tree3c072207ca94e5493682906b2703b3d7a548391b /include/sys/sendfile.h
parent4c316e6c2c8d44bfdda55fa6bae8efdd345eb14b (diff)
Implement sendfile64
-Erik
Diffstat (limited to 'include/sys/sendfile.h')
-rw-r--r--include/sys/sendfile.h31
1 files changed, 23 insertions, 8 deletions
diff --git a/include/sys/sendfile.h b/include/sys/sendfile.h
index ea474048c..797822b9f 100644
--- a/include/sys/sendfile.h
+++ b/include/sys/sendfile.h
@@ -1,4 +1,5 @@
-/* Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.
+/* sendfile -- copy data directly from one file descriptor to another
+ Copyright (C) 1998,99,01,2002 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -22,16 +23,30 @@
#include <features.h>
#include <sys/types.h>
-#ifdef __USE_FILE_OFFSET64
-# error "<sys/sendfile.h> cannot be used with _FILE_OFFSET_BITS=64"
-#endif
-
__BEGIN_DECLS
-/* Send COUNT bytes from file associated with IN_FD starting at OFFSET to
- descriptor OUT_FD. */
-extern ssize_t sendfile (int __out_fd, int __in_fd, off_t *offset,
+/* Send up to COUNT bytes from file associated with IN_FD starting at
+ *OFFSET to descriptor OUT_FD. Set *OFFSET to the IN_FD's file position
+ following the read bytes. If OFFSET is a null pointer, use the normal
+ file position instead. Return the number of written bytes, or -1 in
+ case of error. */
+#ifndef __USE_FILE_OFFSET64
+extern ssize_t sendfile (int __out_fd, int __in_fd, off_t *__offset,
size_t __count) __THROW;
+#else
+# ifdef __REDIRECT
+extern ssize_t __REDIRECT (sendfile,
+ (int __out_fd, int __in_fd, __off64_t *__offset,
+ size_t __count) __THROW,
+ sendfile64);
+# else
+# define sendfile sendfile64
+# endif
+#endif
+#ifdef __USE_LARGEFILE64
+extern ssize_t sendfile64 (int __out_fd, int __in_fd, __off64_t *__offset,
+ size_t __count) __THROW;
+#endif
__END_DECLS